@@ -213,11 +213,26 @@ class Runner:
 
         # remove exclusions
         for lintable in self.lintables.copy():
+            # 1. Standard exclusion check
             if self.is_excluded(lintable):
                 _logger.debug("Excluded %s", lintable)
                 self.lintables.remove(lintable)
                 continue
+
+            # 2. Handle load errors (This is where SOPS/Broken YAML crashes)
             if isinstance(lintable.data, States) and lintable.exc:
+                # --- NEW LOGIC FOR #4745 ---
+                # Even if it's 'explicit', if it's broken, we check the exclude_paths
+                # one last time before reporting a 'load-failure'.
+                abs_path = str(lintable.abspath)
+                if any(
+                    abs_path.startswith(p) or fnmatch(abs_path, p)
+                    for p in self.exclude_paths
+                ):
+                    self.lintables.remove(lintable)
+                    continue
+                # --- END NEW LOGIC ---
+
                 line = 1
                 column = None
                 detail = ""
@@ -231,7 +246,11 @@ class Runner:
                     sub_tag = "yaml"
                     if isinstance(lintable.exc.args, tuple):
                         message = lintable.exc.args[0]
-                    detail = lintable.exc.__cause__.problem
+                    detail = (
+                        str(lintable.exc.__cause__.problem)
+                        if lintable.exc.__cause__.problem
+                        else ""
+                    )
                     if lintable.exc.__cause__.problem_mark:
                         line = lintable.exc.__cause__.problem_mark.line + 1
                         column = lintable.exc.__cause__.problem_mark.column + 1
@@ -261,7 +280,6 @@ class Runner:
 
         # -- phase 1 : syntax check in parallel --
         if not self.skip_ansible_syntax_check:
-            # app = get_app(cached=True)
 
             def worker(lintable: Lintable) -> list[MatchError]:
                 return self._get_ansible_syntax_check_matches(
